@@ -1,7 +1,7 @@
 /*
  * ct_codebox.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -114,7 +114,6 @@ void CtTextCell::set_syntax_highlighting(const std::string& syntaxHighlighting,
     }
 }
 
-
 const Gsv::DrawSpacesFlags CtCodebox::DRAW_SPACES_FLAGS = Gsv::DRAW_SPACES_ALL & ~Gsv::DRAW_SPACES_NEWLINE;
 
 CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
@@ -142,7 +141,8 @@ CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
         else {
             _scrolledwindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
         }
-    } else {
+    }
+    else {
         _scrolledwindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_NEVER);
         _ctTextview.set_wrap_mode(Gtk::WrapMode::WRAP_NONE);
     }
@@ -174,6 +174,16 @@ CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
         }
         return false;
     });
+    _scrolledwindow.get_vscrollbar()->signal_value_changed().connect([this](){
+        if (_pCtMainWin->get_ct_config()->codeboxAutoResize) {
+            _scrolledwindow.get_vscrollbar()->set_value(0);
+        }
+    });
+    _scrolledwindow.get_hscrollbar()->signal_value_changed().connect([this](){
+        if (_pCtMainWin->get_ct_config()->codeboxAutoResize) {
+            _scrolledwindow.get_hscrollbar()->set_value(0);
+        }
+    });
     _uCtPairCodeboxMainWin.reset(new CtPairCodeboxMainWin{this, _pCtMainWin});
     g_signal_connect(G_OBJECT(_ctTextview.gobj()), "cut-clipboard", G_CALLBACK(CtClipboard::on_cut_clipboard), _uCtPairCodeboxMainWin.get());
     g_signal_connect(G_OBJECT(_ctTextview.gobj()), "copy-clipboard", G_CALLBACK(CtClipboard::on_copy_clipboard), _uCtPairCodeboxMainWin.get());
@@ -283,7 +293,7 @@ bool CtCodebox::_on_key_press_event(GdkEventKey* event)
         return false;
     if (event->state & Gdk::CONTROL_MASK) {
         _pCtMainWin->get_ct_actions()->curr_codebox_anchor = this;
-        if (event->keyval == GDK_KEY_period) {
+        if (event->keyval == GDK_KEY_backslash) {
             if (event->state & Gdk::MOD1_MASK)
                 _pCtMainWin->get_ct_actions()->codebox_decrease_width();
             else
