@@ -1,7 +1,7 @@
 /*
  * ct_config.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -250,11 +250,14 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_boolean(_currentGroup, "spaces_instead_tabs", spacesInsteadTabs);
     _uKeyFile->set_integer(_currentGroup, "tabs_width", tabsWidth);
     _uKeyFile->set_integer(_currentGroup, "anchor_size", anchorSize);
+    _uKeyFile->set_integer(_currentGroup, "latex_size_dpi", latexSizeDpi);
     _uKeyFile->set_integer(_currentGroup, "embfile_icon_size", embfileIconSize);
     _uKeyFile->set_boolean(_currentGroup, "embfile_show_filename", embfileShowFileName);
     _uKeyFile->set_integer(_currentGroup, "embfile_max_size", embfileMaxSize);
     _uKeyFile->set_boolean(_currentGroup, "line_wrapping", lineWrapping);
     _uKeyFile->set_boolean(_currentGroup, "auto_smart_quotes", autoSmartQuotes);
+    _uKeyFile->set_boolean(_currentGroup, "camelcase_autolink", camelCaseAutoLink);
+    _uKeyFile->set_boolean(_currentGroup, "url_autolink", urlAutoLink);
     _uKeyFile->set_boolean(_currentGroup, "triple_click_paragraph", tripleClickParagraph);
     _uKeyFile->set_boolean(_currentGroup, "enable_symbol_autoreplace", enableSymbolAutoreplace);
 #ifdef MD_AUTO_REPLACEMENT
@@ -529,11 +532,14 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_bool_from_keyfile("spaces_instead_tabs", &spacesInsteadTabs);
     _populate_int_from_keyfile("tabs_width", &tabsWidth);
     _populate_int_from_keyfile("anchor_size", &anchorSize);
+    _populate_int_from_keyfile("latex_size_dpi", &latexSizeDpi);
     _populate_int_from_keyfile("embfile_icon_size", &embfileIconSize);
     _populate_bool_from_keyfile("embfile_show_filename", &embfileShowFileName);
     _populate_int_from_keyfile("embfile_max_size", &embfileMaxSize);
     _populate_bool_from_keyfile("line_wrapping", &lineWrapping);
     _populate_bool_from_keyfile("auto_smart_quotes", &autoSmartQuotes);
+    _populate_bool_from_keyfile("camelcase_autolink", &camelCaseAutoLink);
+    _populate_bool_from_keyfile("url_autolink", &urlAutoLink);
     _populate_bool_from_keyfile("triple_click_paragraph", &tripleClickParagraph);
     _populate_bool_from_keyfile("enable_symbol_autoreplace", &enableSymbolAutoreplace);
 #ifdef MD_AUTO_REPLACEMENT
