@@ -1,7 +1,7 @@
 /*
  * ct_config.h
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -102,11 +102,14 @@ public:
     bool                                        spacesInsteadTabs{false};
     int                                         tabsWidth{4};
     int                                         anchorSize{16};
+    int                                         latexSizeDpi{140};
     int                                         embfileIconSize{48};
     bool                                        embfileShowFileName{true};
     int                                         embfileMaxSize{10};
     bool                                        lineWrapping{true};
     bool                                        autoSmartQuotes{true};
+    bool                                        urlAutoLink{true};
+    bool                                        camelCaseAutoLink{true};
     bool                                        tripleClickParagraph{false};
     bool                                        enableSymbolAutoreplace{true};
 #ifdef MD_AUTO_REPLACEMENT
