@@ -1,7 +1,7 @@
 /*
- * ct_extern const.h
+ * ct_const.h
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -239,7 +239,7 @@ const inline static gchar* TOOLBAR_VEC_DEFAULT {
     "tree_add_node,tree_add_subnode,separator,go_node_prev,go_node_next,"
     "separator,*,ct_save,export_pdf,separator,"
     "find_in_allnodes,separator,handle_bull_list,handle_num_list,handle_todo_list,fmt_indent,fmt_unindent,"
-    "separator,handle_image,handle_table,handle_codebox,handle_embfile,"
+    "separator,handle_image,handle_table,handle_codebox,handle_latex,handle_embfile,"
     "handle_link,handle_anchor,separator,fmt_clone,fmt_latest,fmt_rm,fmt_color_fg,"
     "fmt_color_bg,fmt_bold,fmt_italic,fmt_underline,fmt_strikethrough,"
     "fmt_h1,fmt_h2,fmt_h3,fmt_small,fmt_superscript,fmt_subscript,fmt_monospace"
@@ -247,8 +247,8 @@ const inline static gchar* TOOLBAR_VEC_DEFAULT {
 
 const inline static gchar* LANG_DEFAULT{"default"};
 
-const inline static std::array<const gchar*, 28> AVAILABLE_LANGS {
-    LANG_DEFAULT, "bg", "cs", "de", "el", "en", "es", "fi", "fr", "hr", "hy", "it",
+const inline static std::vector<const gchar*> AVAILABLE_LANGS {
+    LANG_DEFAULT, "ar", "bg", "cs", "de", "el", "en", "es", "fi", "fr", "hi_IN", "hr", "hu", "hy", "it",
     "ja", "kk_KZ", "ko", "lt", "nl", "pl", "pt", "pt_BR", "ro", "ru", "sl", "sv", "tr", "uk", "zh_CN", "zh_TW"
 };
 
@@ -258,8 +258,7 @@ const inline static int NODE_ICON_NO_ICON_ID       {26};
 const inline static int NODE_ICON_SIZE             {16};
 const inline static int MAX_TOOLTIP_LINK_CHARS     {150};
 
-// former NODES_STOCK
-const inline static std::array<const gchar*, 128> NODE_CUSTOM_ICONS {
+const inline static std::vector<const gchar*> NODE_CUSTOM_ICONS {
     nullptr,            // NEVER USED
     "ct_circle-green",  //  1
     "ct_circle-yellow", //  2
@@ -387,7 +386,28 @@ const inline static std::array<const gchar*, 128> NODE_CUSTOM_ICONS {
     "ct_ro",           // 124
     "ct_hr",           // 125
     "ct_ghost",        // 126
-    "ct_pt"            // 127
+    "ct_pt",           // 127
+    "ct_zh_TW",        // 128
+    "ct_hi_IN",        // 129
+    "ct_ar",           // 130
+    "ct_hu",           // 131
+    "ct_heart_ukraine",// 132
+    "ct_microchip",    // 133
+    "ct_ansible",      // 134
+    "ct_aws",          // 135
+    "ct_azure",        // 136
+    "ct_docker",       // 137
+    "ct_gcp",          // 138
+    "ct_kubernetes",   // 139
+};
+
+const inline static std::vector<int> NODE_CUSTOM_ICONS_ORDERED {
+    132, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 19, 20, 133,
+    /*coding start*/17, 21, 22, 23, 24, 38, 46, 47, 48, 49/*coding end*/,
+    114, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 39, 40, 41, 42, 43, 44, 45, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 126, 113,
+    /*os start*/115, 116, 117, 118, 119, 120, 121/*os end*/,
+    /*devops start*/134, 135, 136, 137, 138, 139/*devops end*/,
+    /*flags start*/73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 122, 123, 124, 125, 127, 128, 129, 130, 131/*flags end*/
 };
 
 // former NODES_ICONS
@@ -467,6 +487,7 @@ const inline static Glib::ustring TARGET_CTD_CODEBOX = "CTD_CODEBOX";
 const inline static Glib::ustring TARGET_WIN_HTML = "HTML Format";
 const inline static std::vector<Glib::ustring> TARGETS_HTML = {"text/html", TARGET_WIN_HTML};
 const inline static Glib::ustring TARGET_URI_LIST = "text/uri-list";
+const inline static Glib::ustring TARGET_GTK_TEXT_BUFFER_CONTENTS = "GTK_TEXT_BUFFER_CONTENTS";
 const inline static std::vector<Glib::ustring> TARGETS_PLAIN_TEXT = {"UTF8_STRING", "COMPOUND_TEXT", "STRING", "TEXT"};
 const inline static std::vector<Glib::ustring> TARGETS_IMAGES = {"image/png", "image/jpeg", "image/bmp", "image/tiff", "image/x-MS-bmp", "image/x-bmp"};
 const inline static Glib::ustring TARGET_WINDOWS_FILE_NAME = "FileName";
