@@ -81,8 +81,7 @@ bool CtExport2Html::prepare_html_folder(fs::path dir_place, fs::path new_folder,
 void CtExport2Html::node_export_to_html(CtTreeIter tree_iter, const CtExportOptions& options, const Glib::ustring& index, int sel_start, int sel_end)
 {
     Glib::ustring html_text = str::format(HTML_HEADER, tree_iter.get_node_name());
-    if (index != "" && options.index_in_page)
-    {
+    if (not index.empty() and options.index_in_page) {
         auto script = R"HTML(
             <script type='text/javascript'>
                 function in_frame () { try { return window.self !== window.top; } catch (e) { return true; } }
@@ -94,48 +93,56 @@ void CtExport2Html::node_export_to_html(CtTreeIter tree_iter, const CtExportOpti
         html_text = str::replace(html_text, "<script></script>", script);
     }
     html_text += "<div class='page'>";
-    if (options.include_node_name)
+    if (options.include_node_name) {
         html_text += "<h1 class='title'>" + tree_iter.get_node_name() + "</h1><br/>";
-
+    }
     std::vector<Glib::ustring> html_slots;
     std::vector<CtAnchoredWidget*> widgets;
-    if (tree_iter.get_node_is_rich_text())
-    {
+    if (tree_iter.get_node_is_text()) {
+        Glib::ustring node_html_text;
         _html_get_from_treestore_node(tree_iter, sel_start, sel_end, html_slots, widgets);
-        int images_count = 0;
-        for (size_t i = 0; i < html_slots.size(); ++i)
-        {
-            html_text += html_slots[i];
-            if (i < widgets.size())
-            {
-                try
-                {
+        int images_count{0};
+        for (size_t i = 0; i < html_slots.size(); ++i) {
+            node_html_text += html_slots[i];
+            if (i < widgets.size()) {
+                try {
                     if (CtImageEmbFile* embfile = dynamic_cast<CtImageEmbFile*>(widgets[i]))
-                        html_text += _get_embfile_html(embfile, tree_iter, _embed_dir);
+                        node_html_text += _get_embfile_html(embfile, tree_iter, _embed_dir);
                     else if (CtImage* image = dynamic_cast<CtImage*>(widgets[i]))
-                        html_text += _get_image_html(image, _images_dir, images_count, &tree_iter);
+                        node_html_text += _get_image_html(image, _images_dir, images_count, &tree_iter);
                     else if (CtTable* table = dynamic_cast<CtTable*>(widgets[i]))
-                        html_text += _get_table_html(table);
+                        node_html_text += _get_table_html(table);
                     else if (CtCodebox* codebox = dynamic_cast<CtCodebox*>(widgets[i]))
-                        html_text += _get_codebox_html(codebox);
+                        node_html_text += _get_codebox_html(codebox);
                 }
-                catch (std::exception& ex)
-                {
+                catch (std::exception& ex) {
                     spdlog::debug("caught ex: {}", ex.what());
                 }
-                catch (...)
-                {
+                catch (...) {
                     spdlog::debug("unknown ex");
                 }
             }
         }
+        auto rTextBuffer = tree_iter.get_node_text_buffer();
+        Gtk::TextIter start_iter = rTextBuffer->get_iter_at_offset(sel_start == -1 ? 0 : sel_start);
+        Gtk::TextIter end_iter = sel_end == -1 ? rTextBuffer->end() : rTextBuffer->get_iter_at_offset(sel_end);
+        const std::vector<bool> rtl_for_lines = CtStrUtil::get_rtl_for_lines(start_iter.get_text(end_iter));
+        std::vector<Glib::ustring> node_lines = str::split(node_html_text, CtConst::CHAR_NEWLINE);
+        const size_t lastIdx = node_lines.size() - 1;
+        for (size_t i = 0; i < node_lines.size(); ++i) {
+            if (i < lastIdx or not node_lines.at(i).empty()) {
+                if (rtl_for_lines.at(i)) html_text += "<p dir=\"rtl\">" + node_lines.at(i) + "</p>";
+                else html_text += "<p>" + node_lines.at(i) + "</p>";
+            }
+        }
     }
-    else
+    else {
         html_text += _html_get_from_code_buffer(tree_iter.get_node_text_buffer(), sel_start, sel_end, tree_iter.get_node_syntax_highlighting());
-
-    if (index != "" && !options.index_in_page)
+    }
+    if (not index.empty() and not options.index_in_page) {
         html_text += Glib::ustring("<p align=\"center\">") + "<img src=\"" + Glib::build_filename("images", "home.svg") + "\" height=\"22\" width=\"22\">" +
                 CtConst::CHAR_SPACE + CtConst::CHAR_SPACE + "<a href=\"index.html\">" + _("Index") + "</a></p>";
+    }
     html_text += "</div>"; // div class='page'
     html_text += HTML_FOOTER;
 
@@ -216,48 +223,53 @@ void CtExport2Html::nodes_all_export_to_single_html(bool all_tree, const CtExpor
         html_text += "<h1 class='title level-" + std::to_string(node_level) + "'>" + tree_iter.get_node_name() + "</h1><br/>";
         std::vector<Glib::ustring> html_slots;
         std::vector<CtAnchoredWidget*> widgets;
-        if (tree_iter.get_node_is_rich_text())
-        {
+        if (tree_iter.get_node_is_text()) {
+            Glib::ustring node_html_text;
             _html_get_from_treestore_node(tree_iter, -1, -1, html_slots, widgets);
             int images_count = 0;
-            for (size_t i = 0; i < html_slots.size(); ++i)
-            {
-                html_text += html_slots[i];
-                if (i < widgets.size())
-                {
-                    try
-                    {
+            for (size_t i = 0; i < html_slots.size(); ++i) {
+                node_html_text += html_slots[i];
+                if (i < widgets.size()) {
+                    try {
                         if (CtImageEmbFile* embfile = dynamic_cast<CtImageEmbFile*>(widgets[i]))
-                            html_text += _get_embfile_html(embfile, tree_iter, _embed_dir);
+                            node_html_text += _get_embfile_html(embfile, tree_iter, _embed_dir);
                         else if (CtImage* image = dynamic_cast<CtImage*>(widgets[i]))
-                            html_text += _get_image_html(image, _images_dir, images_count, &tree_iter);
+                            node_html_text += _get_image_html(image, _images_dir, images_count, &tree_iter);
                         else if (CtTable* table = dynamic_cast<CtTable*>(widgets[i]))
-                            html_text += _get_table_html(table);
+                            node_html_text += _get_table_html(table);
                         else if (CtCodebox* codebox = dynamic_cast<CtCodebox*>(widgets[i]))
-                            html_text += _get_codebox_html(codebox);
+                            node_html_text += _get_codebox_html(codebox);
                     }
-                    catch (std::exception& ex)
-                    {
+                    catch (std::exception& ex) {
                         spdlog::debug("caught ex: {}", ex.what());
                     }
-                    catch (...)
-                    {
+                    catch (...) {
                         spdlog::debug("unknown ex");
                     }
                 }
             }
+            const std::vector<bool> rtl_for_lines = CtStrUtil::get_rtl_for_lines(tree_iter.get_node_text_buffer()->get_text());
+            std::vector<Glib::ustring> node_lines = str::split(node_html_text, CtConst::CHAR_NEWLINE);
+            const size_t lastIdx = node_lines.size() - 1;
+            for (size_t i = 0; i < node_lines.size(); ++i) {
+                if (i < lastIdx or not node_lines.at(i).empty()) {
+                    if (rtl_for_lines.at(i)) html_text += "<p dir=\"rtl\">" + node_lines.at(i) + "</p>";
+                    else html_text += "<p>" + node_lines.at(i) + "</p>";
+                }
+            }
         }
-        else
+        else {
             html_text += _html_get_from_code_buffer(tree_iter.get_node_text_buffer(), -1, -1, tree_iter.get_node_syntax_highlighting());
+        }
         html_text += "</div>"; // div class='page'
         rFileStream->write(html_text.c_str(), html_text.bytes());
         html_text.clear();
 
-        for (auto& child: tree_iter->children())
+        for (auto& child : tree_iter->children()) {
             traverseFunc(_pCtMainWin->get_tree_store().to_ct_tree_iter(child), node_level + 1);
+        }
     };
 
-
     Glib::ustring html_header = str::format(HTML_HEADER, _pCtMainWin->get_ct_storage()->get_file_name());
     rFileStream->write(html_header.c_str(), html_header.bytes());
 
@@ -299,30 +311,40 @@ void CtExport2Html::_tree_links_text_iter(CtTreeIter tree_iter, Glib::ustring& t
 }
 
 // Returns the HTML given the text buffer and iter bounds
-Glib::ustring CtExport2Html::selection_export_to_html(Glib::RefPtr<Gtk::TextBuffer> text_buffer, Gtk::TextIter start_iter,
-                                                      Gtk::TextIter end_iter, const Glib::ustring& syntax_highlighting)
+Glib::ustring CtExport2Html::selection_export_to_html(Glib::RefPtr<Gtk::TextBuffer> text_buffer,
+                                                      Gtk::TextIter start_iter,
+                                                      Gtk::TextIter end_iter,
+                                                      const Glib::ustring& syntax_highlighting)
 {
     Glib::ustring html_text = str::format(HTML_HEADER, "");
-    if (syntax_highlighting == CtConst::RICH_TEXT_ID)
-    {
-        int images_count = 0;
+    if (syntax_highlighting == CtConst::RICH_TEXT_ID) {
+        Glib::ustring node_html_text;
+        int images_count{0};
         fs::path tempFolder = _pCtMainWin->get_ct_tmp()->getHiddenDirPath("IMAGE_TEMP_FOLDER");
-
         int start_offset = start_iter.get_offset();
         std::list<CtAnchoredWidget*> widgets = _pCtMainWin->curr_tree_iter().get_anchored_widgets(start_iter.get_offset(), end_iter.get_offset());
-        for (CtAnchoredWidget* widget: widgets)
-        {
+        for (CtAnchoredWidget* widget : widgets) {
             int end_offset = widget->getOffset();
-            html_text +=_html_process_slot(start_offset, end_offset, text_buffer);
-            if (CtImage* image = dynamic_cast<CtImage*>(widget)) html_text += _get_image_html(image, tempFolder, images_count, nullptr);
-            else if (CtTable* table = dynamic_cast<CtTable*>(widget)) html_text += _get_table_html(table);
-            else if (CtCodebox* codebox = dynamic_cast<CtCodebox*>(widget)) html_text += _get_codebox_html(codebox);
+            node_html_text +=_html_process_slot(start_offset, end_offset, text_buffer);
+            if (CtImage* image = dynamic_cast<CtImage*>(widget)) node_html_text += _get_image_html(image, tempFolder, images_count, nullptr);
+            else if (CtTable* table = dynamic_cast<CtTable*>(widget)) node_html_text += _get_table_html(table);
+            else if (CtCodebox* codebox = dynamic_cast<CtCodebox*>(widget)) node_html_text += _get_codebox_html(codebox);
             start_offset = end_offset;
         }
-        html_text += _html_process_slot(start_offset, end_iter.get_offset(), text_buffer);
+        node_html_text += _html_process_slot(start_offset, end_iter.get_offset(), text_buffer);
+
+        std::vector<bool> rtl_for_lines = CtStrUtil::get_rtl_for_lines(start_iter.get_text(end_iter));
+        std::vector<Glib::ustring> node_lines = str::split(node_html_text, CtConst::CHAR_NEWLINE);
+        while (rtl_for_lines.size() < node_lines.size()) { rtl_for_lines.push_back(false); }
+        const size_t lastIdx = node_lines.size() - 1;
+        for (size_t i = 0; i < node_lines.size(); ++i) {
+            if (i < lastIdx or not node_lines.at(i).empty()) {
+                if (rtl_for_lines.at(i)) html_text += "<p dir=\"rtl\">" + node_lines.at(i) + "</p>";
+                else html_text += "<p>" + node_lines.at(i) + "</p>";
+            }
+        }
     }
-    else
-    {
+    else {
         Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(text_buffer);
         html_text += _html_get_from_code_buffer(gsv_buffer, start_iter.get_offset(), end_iter.get_offset(), syntax_highlighting);
     }
@@ -495,8 +517,11 @@ Glib::ustring CtExport2Html::_html_get_from_code_buffer(const Glib::RefPtr<Gsv::
 }
 
 // Given a treestore iter returns the HTML rich text
-void CtExport2Html::_html_get_from_treestore_node(CtTreeIter node_iter, int sel_start, int sel_end,
-                                                  std::vector<Glib::ustring>& out_slots, std::vector<CtAnchoredWidget*>& out_widgets)
+void CtExport2Html::_html_get_from_treestore_node(CtTreeIter node_iter,
+                                                  int sel_start,
+                                                  int sel_end,
+                                                  std::vector<Glib::ustring>& out_slots,
+                                                  std::vector<CtAnchoredWidget*>& out_widgets)
 {
     auto curr_buffer = node_iter.get_node_text_buffer();
     auto widgets = node_iter.get_anchored_widgets(sel_start, sel_end);
@@ -504,8 +529,7 @@ void CtExport2Html::_html_get_from_treestore_node(CtTreeIter node_iter, int sel_
 
     out_slots.clear();
     int start_offset = sel_start == -1 ? 0 : sel_start;
-    for (auto widget: out_widgets)
-    {
+    for (auto widget : out_widgets) {
         int end_offset = widget->getOffset();
         out_slots.push_back(_html_process_slot(start_offset, end_offset, curr_buffer));
         start_offset = end_offset;
@@ -516,18 +540,18 @@ void CtExport2Html::_html_get_from_treestore_node(CtTreeIter node_iter, int sel_
         out_slots.push_back(_html_process_slot(start_offset, sel_end, curr_buffer));
 }
 
-
 // Process a Single HTML Slot
 Glib::ustring CtExport2Html::_html_process_slot(int start_offset, int end_offset, Glib::RefPtr<Gtk::TextBuffer> curr_buffer)
 {
     Glib::ustring curr_html_text = "";
-    CtTextIterUtil::generic_process_slot(start_offset, end_offset, curr_buffer,
-                                         [&](Gtk::TextIter& start_iter, Gtk::TextIter& curr_iter, CtCurrAttributesMap& curr_attributes) {
+    CtTextIterUtil::SerializeFunc f_html_serialise = [&](Gtk::TextIter& start_iter,
+                                                         Gtk::TextIter& curr_iter,
+                                                         CtCurrAttributesMap& curr_attributes)
+    {
         curr_html_text += _html_text_serialize(start_iter, curr_iter, curr_attributes);
-    });
+    };
+    CtTextIterUtil::generic_process_slot(start_offset, end_offset, curr_buffer, f_html_serialise);
 
-    curr_html_text = str::replace(curr_html_text, "<br/><p ", "<p ");
-    curr_html_text = str::replace(curr_html_text, "</p><br/>", "</p>");
     for (auto header : {CtConst::TAG_PROP_VAL_H1, CtConst::TAG_PROP_VAL_H2, CtConst::TAG_PROP_VAL_H3,
                         CtConst::TAG_PROP_VAL_H4, CtConst::TAG_PROP_VAL_H5, CtConst::TAG_PROP_VAL_H6}) {
         curr_html_text = str::replace(curr_html_text, ("</" + Glib::ustring{header} + "><" + Glib::ustring{header} + " >").c_str(), "");
@@ -540,10 +564,6 @@ Glib::ustring CtExport2Html::_html_text_serialize(Gtk::TextIter start_iter,
                                                   Gtk::TextIter end_iter,
                                                   const CtCurrAttributesMap& curr_attributes)
 {
-    Glib::ustring inner_text = str::xml_escape(start_iter.get_text(end_iter));
-    if (inner_text.empty()) return inner_text;
-    inner_text = str::replace(inner_text, CtConst::CHAR_NEWLINE, "<br />");
-
     Glib::ustring html_attrs;
     bool superscript_active{false};
     bool subscript_active{false};
@@ -551,6 +571,7 @@ Glib::ustring CtExport2Html::_html_text_serialize(Gtk::TextIter start_iter,
     bool bold_active{false};
     bool italic_active{false};
     Glib::ustring hN_active;
+    Glib::ustring href;
     for (auto tag_property : CtConst::TAG_PROPERTIES) {
         if (curr_attributes.at(tag_property).empty()) {
             continue;
@@ -629,34 +650,46 @@ Glib::ustring CtExport2Html::_html_text_serialize(Gtk::TextIter start_iter,
         }
         else if (tag_property == CtConst::TAG_LINK) {
             // <a href="http://www.example.com/">link-text goes here</a>
-            Glib::ustring href = _get_href_from_link_prop_val(property_value);
-            if (href.empty()) {
-                continue;
-            }
-            Glib::ustring html_text = "<a href=\"" + href + "\">" + inner_text + "</a>";
-            return html_text;
+            href = _get_href_from_link_prop_val(property_value);
+            continue;
         }
         html_attrs += Glib::ustring{tag_property.data()} + ":" + property_value + ";";
     }
-    Glib::ustring tagged_text;
-    if (html_attrs.empty() || inner_text == "<br />") {
-        tagged_text = inner_text;
-    }
-    else {
-        if (not hN_active.empty())
-            tagged_text = Glib::ustring{"<"} + hN_active + ">" + inner_text + Glib::ustring{"</"} + hN_active + ">";
-        else if (html_attrs.find("x-small") != Glib::ustring::npos)
-            tagged_text = "<small>" + inner_text + "</small>";
-        else
-            tagged_text = "<span style=\"" + html_attrs + "\">" + inner_text + "</span>";
-    }
-    if (superscript_active) tagged_text = "<sup>" + tagged_text + "</sup>";
-    if (subscript_active) tagged_text = "<sub>" + tagged_text + "</sub>";
-    if (monospace_active) tagged_text = "<code>" + tagged_text + "</code>";
-    if (bold_active) tagged_text = "<strong>" + tagged_text + "</strong>";
-    if (italic_active) tagged_text = "<em>" + tagged_text + "</em>";
 
-    return tagged_text;
+    // split by \n to support RTL lines
+    Glib::ustring html_text;
+    std::vector<Glib::ustring> lines = str::split(start_iter.get_text(end_iter), CtConst::CHAR_NEWLINE);
+    const size_t lastIdx = lines.size() - 1;
+    for (size_t i = 0; i < lines.size(); ++i) {
+        Glib::ustring tagged_text = str::xml_escape(lines[i]);
+
+        if (not hN_active.empty()) {
+            tagged_text = Glib::ustring{"<"} + hN_active + ">" + tagged_text + Glib::ustring{"</"} + hN_active + ">";
+        }
+        else if (not href.empty()) {
+            tagged_text = "<a href=\"" + href + "\">" + tagged_text + "</a>";
+        }
+        else if (not html_attrs.empty()) {
+            if (html_attrs.find("x-small") != Glib::ustring::npos) {
+                tagged_text = "<small>" + tagged_text + "</small>";
+            }
+            else {
+                tagged_text = "<span style=\"" + html_attrs + "\">" + tagged_text + "</span>";
+            }
+        }
+        if (superscript_active) tagged_text = "<sup>" + tagged_text + "</sup>";
+        if (subscript_active) tagged_text = "<sub>" + tagged_text + "</sub>";
+        if (monospace_active) tagged_text = "<code>" + tagged_text + "</code>";
+        if (bold_active) tagged_text = "<strong>" + tagged_text + "</strong>";
+        if (italic_active) tagged_text = "<em>" + tagged_text + "</em>";
+        html_text += tagged_text;
+
+        // add '\n' between lines
+        if (i < lastIdx) {
+            html_text += CtConst::CHAR_NEWLINE;
+        }
+    }
+    return html_text;
 }
 
 std::string CtExport2Html::_get_href_from_link_prop_val(Glib::ustring link_prop_val)
@@ -714,7 +747,8 @@ Glib::ustring CtExport2Html::_get_object_alignment_string(Glib::ustring alignmen
 // Get the HTML page filename given the tree iter
 Glib::ustring CtExport2Html::_get_html_filename(CtTreeIter tree_iter)
 {
-    Glib::ustring name = CtMiscUtil::get_node_hierarchical_name(tree_iter, "--", true, true, ".html");
+    Glib::ustring name = CtMiscUtil::get_node_hierarchical_name(tree_iter, "--"/*separator*/,
+        true/*for_filename*/, true/*root_to_leaf*/, true/*trail_node_id*/, ".html"/*trailer*/);
     return str::replace(name, "#", "~");
 }
 
