@@ -52,7 +52,7 @@ public:
     void set_modified_false() override {}
 
     void save(const fs::path& file_name, const Glib::ustring& type);
-    Glib::RefPtr<Gdk::Pixbuf> get_pixbuf() { return _rPixbuf; }
+    Glib::RefPtr<Gdk::Pixbuf> get_pixbuf() const { return _rPixbuf; }
 
 protected:
     Gtk::Image _image;
@@ -129,6 +129,9 @@ public:
     static const std::string LatexSpecialFilename;
     static const Glib::ustring LatexTextDefault;
 
+    static void ensureRenderingBinariesTested();
+    static Glib::ustring getRenderingErrorMessage();
+
     void to_xml(xmlpp::Element* p_node_parent, const int offset_adjustment, CtStorageCache* cache) override;
     bool to_sqlite(sqlite3* pDb, const gint64 node_id, const int offset_adjustment, CtStorageCache* cache) override;
     CtAnchWidgType get_type() override { return CtAnchWidgType::ImageLatex; }
@@ -146,6 +149,9 @@ private:
     bool _on_button_press_event(GdkEventButton* event);
 
 protected:
+    static bool   _renderingBinariesTested;
+    static bool   _renderingBinariesLatexOk;
+    static bool   _renderingBinariesDviPngOk;
     Glib::ustring _latexText;
     const size_t  _uniqueId;
 };
@@ -167,7 +173,7 @@ public:
     CtAnchWidgType get_type() override { return CtAnchWidgType::ImageEmbFile; }
     std::shared_ptr<CtAnchoredWidgetState> get_state() override;
 
-    const fs::path&      get_file_name() { return _fileName; }
+    const fs::path&      get_file_name() const { return _fileName; }
     void                 set_file_name(const fs::path& path) { _fileName = path; }
     const std::string&   get_raw_blob() { return _rawBlob; }
     void                 set_raw_blob(const std::string& buffer) { _rawBlob = buffer; }
