@@ -1,7 +1,7 @@
 ﻿/*
  * ct_main_win.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -53,7 +53,7 @@ CtMainWin::CtMainWin(bool                            no_gui,
 
     _uCtActions.reset(new CtActions{this});
     _uCtMenu.reset(new CtMenu{pCtConfig, _uCtActions.get()});
-    _uCtPrint.reset(new CtPrint{});
+    _uCtPrint.reset(new CtPrint{this});
     _uCtStorage.reset(CtStorageControl::create_dummy_storage(this));
 
     _scrolledwindowTree.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
@@ -174,7 +174,8 @@ CtMainWin::CtMainWin(bool                            no_gui,
         else {
             present();
         }
-        _hPaned.property_position() = _pCtConfig->hpanedPos; // must be after present() (#1534)
+        while (gtk_events_pending()) gtk_main_iteration();
+        _hPaned.property_position() = _pCtConfig->hpanedPos; // must be after present() + process events pending (#1534, #1918)
         _ctTextview.signal_size_allocate().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_size_allocate));
         signal_configure_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_window_configure_event), false);
 
@@ -542,7 +543,7 @@ void CtMainWin::menu_set_items_recent_documents()
             }
         }
         else {
-            g_autofree gchar* title = g_strdup_printf(_("The Document %s was Not Found"), filepath.c_str());
+            g_autofree gchar* title = g_strdup_printf(_("The Document %s was Not Found"), str::xml_escape(filepath).c_str());
             CtDialogs::error_dialog(Glib::ustring{title}, *this);
             _pCtConfig->recentDocsFilepaths.move_or_push_back(fs_canonicalize_filename(filepath));
             menu_set_items_recent_documents();
@@ -572,7 +573,7 @@ void CtMainWin::menu_set_items_recent_documents()
 void CtMainWin::menu_set_visible_exit_app(bool visible)
 {
     if (auto quit_label = CtMenu::get_accel_label(CtMenu::find_menu_item(_pMenuBar, "quit_app"))) {
-        quit_label->set_label(visible ? _("Hide") : _("Quit"));
+        quit_label->set_label(visible ? _("_Hide") : _("_Quit"));
         quit_label->set_tooltip_markup(visible ?  _("Hide the Window") : _("Quit the Application"));
     }
     CtMenu::find_menu_item(_pMenuBar, "exit_app")->set_visible(visible);
@@ -587,7 +588,12 @@ void CtMainWin::menu_rebuild_toolbars(bool new_toolbar)
         _pToolbars = _uCtMenu->build_toolbars(_pRecentDocsMenuToolButton);
         for (auto toolbar = _pToolbars.rbegin(); toolbar != _pToolbars.rend(); ++toolbar) {
             _vboxMain.pack_start(*(*toolbar), false, false);
-            _vboxMain.reorder_child(*(*toolbar), 1);
+            if (not _pCtConfig->menubarInTitlebar) {
+                _vboxMain.reorder_child(*(*toolbar), 1);
+            }
+            else {
+                _vboxMain.reorder_child(*(*toolbar), 0);
+            }
         }
         menu_set_items_recent_documents();
         for (auto pToolbar: _pToolbars) {
@@ -704,3 +710,18 @@ void CtMainWin::update_selected_node_statusbar_info()
     }
     _ctStatusBar.update_status(statusbar_text);
 }
+
+void CtMainWin::tree_node_paste_from_other_window(CtMainWin* pWinToCopyFrom, gint64 nodeIdToCopyFrom)
+{
+    if (not pWinToCopyFrom) {
+        CtDialogs::warning_dialog(_("No Previous Node Copy Was Performed During This Session or the Source Tree is No Longer Available"), *this);
+        return;
+    }
+    CtTreeStore& other_ct_tree_store = pWinToCopyFrom->get_tree_store();
+    CtTreeIter   other_ct_tree_iter = other_ct_tree_store.get_node_from_node_id(nodeIdToCopyFrom);
+    if (not other_ct_tree_iter) {
+        CtDialogs::warning_dialog(_("The Source Tree Node is No Longer Available"), *this);
+        return;
+    }
+    _uCtActions->node_subnodes_paste2(other_ct_tree_iter, pWinToCopyFrom);
+}
