@@ -1,7 +1,7 @@
 /*
  * ct_main_win.h
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -65,6 +65,7 @@ struct CtWinHeader
     Gtk::Label       nameLabel;
     Gtk::Image       lockIcon;
     Gtk::Image       bookmarkIcon;
+    Gtk::Image       ghostIcon;
     Gtk::EventBox    eventBox;
     std::map<Gtk::Button*, gint64> button_to_node_id;
 };
@@ -118,6 +119,8 @@ public:
 
     void update_selected_node_statusbar_info();
 
+    void tree_node_paste_from_other_window(CtMainWin* pWinToCopyFrom, gint64 nodeIdToCopyFrom);
+
     Glib::RefPtr<Gtk::TextBuffer>     curr_buffer() { return _ctTextview.get_buffer(); }
     CtTreeIter                        curr_tree_iter()  {
         return _uCtTreestore->to_ct_tree_iter(_uCtTreeview->get_selection()->get_selected());
@@ -168,8 +171,9 @@ public:
     void window_title_update(std::optional<bool> saveNeeded = std::nullopt);
 
     void window_header_update();
-    void window_header_update_lock_icon(bool show);
-    void window_header_update_bookmark_icon(bool show);
+    void window_header_update_lock_icon(const bool show);
+    void window_header_update_ghost_icon(const bool show);
+    void window_header_update_bookmark_icon(const bool show);
 
     void menu_update_bookmark_menu_item(bool is_bookmarked);
     void menu_set_bookmark_menu_items();
@@ -181,7 +185,13 @@ public:
 
     void config_switch_tree_side();
 
-    void show_hide_toolbars(bool visible)   { for (auto pToolbar: _pToolbars) pToolbar->property_visible() = visible; }
+    void show_hide_toolbars(bool visible)   { for (auto pToolbar : _pToolbars) pToolbar->property_visible() = visible; }
+    void show_hide_menubar(bool visible)    {
+        if (visible) _pScrolledWindowMenuBar->set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_NEVER);
+        else _pScrolledWindowMenuBar->set_policy(Gtk::POLICY_EXTERNAL, Gtk::POLICY_EXTERNAL);
+    }
+    void show_hide_statusbar(bool visible)  { _ctStatusBar.hbox.property_visible() = visible; }
+    void show_hide_tree_lines(bool visible) { _uCtTreeview->set_enable_tree_lines(visible); }
     void set_toolbars_icon_size(int size)   { for (auto pToolbar: _pToolbars) pToolbar->property_icon_size() = CtMiscUtil::getIconSize(size); }
     void show_hide_tree_view(bool visible)  { _scrolledwindowTree.property_visible() = visible; }
     void show_hide_win_header(bool visible) { _ctWinHeader.headerBox.property_visible() = visible; }
@@ -256,7 +266,9 @@ private:
     Gtk::VBox                    _vboxMain;
     Gtk::VBox                    _vboxText;
     Gtk::HPaned                  _hPaned;
+    Gtk::HeaderBar*              _pHeaderBar{nullptr};
     Gtk::MenuBar*                _pMenuBar{nullptr};
+    Gtk::ScrolledWindow*         _pScrolledWindowMenuBar{nullptr};
     std::vector<Gtk::Toolbar*>   _pToolbars;
     CtStatusBar                  _ctStatusBar;
     CtWinHeader                  _ctWinHeader;
@@ -295,7 +307,9 @@ private:
 
 public:
     sigc::signal<void>             signal_app_new_instance = sigc::signal<void>();
-    sigc::signal<void>             signal_show_hide_main_win = sigc::signal<void>();
+    sigc::signal<void>             signal_app_show_hide_main_win = sigc::signal<void>();
+    sigc::signal<void>             signal_app_tree_node_copy = sigc::signal<void>();
+    sigc::signal<void>             signal_app_tree_node_paste = sigc::signal<void>();
     sigc::signal<void, std::function<void(CtMainWin*)>>
                                    signal_app_apply_for_each_window = sigc::signal<void, std::function<void(CtMainWin*)>>();
 
