@@ -1,7 +1,7 @@
 /*
  * ct_menu.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -60,8 +60,8 @@ public:
     const std::string KB_SHIFT   = "<shift>";
     const std::string KB_ALT     = "<alt>";
     const std::string KB_META    = "<meta>";
-    
-    enum POPUP_MENU_TYPE {Node, Text, Code, Link, Codebox, Image, Anchor, EmbFile, PopupMenuNum };
+
+    enum POPUP_MENU_TYPE {Node, Text, Code, Link, Codebox, Image, Latex, Anchor, EmbFile, PopupMenuNum };
 
 public:
    static Gtk::MenuItem* create_menu_item(Gtk::Menu* pMenu, const char* name, const char* image, const char* desc);
@@ -73,19 +73,17 @@ public:
     const std::list<CtMenuAction>& get_actions() { return _actions; }
     Glib::RefPtr<Gtk::AccelGroup> get_accel_group() { return _pAccelGroup; }
 
-    static Gtk::MenuItem*   find_menu_item(Gtk::MenuBar* menuBar, std::string name);
+    static Gtk::MenuItem*   find_menu_item(Gtk::MenuShell* menuShell, std::string name);
     static Gtk::AccelLabel* get_accel_label(Gtk::MenuItem* item);
-    static int              calculate_image_shift(Gtk::MenuItem* menuItem);
 
     std::vector<Gtk::Toolbar*> build_toolbars(Gtk::MenuToolButton*& pRecentDocsMenuToolButton);
     Gtk::MenuBar*              build_menubar();
     Gtk::Menu*                 build_bookmarks_menu(std::list<std::pair<gint64, std::string>>& bookmarks,
-                                                    sigc::slot<void, gint64>& bookmark_action);
+                                                    sigc::slot<void, gint64>& bookmark_action,
+                                                    const bool isTopMenu);
     Gtk::Menu*                 build_recent_docs_menu(const CtRecentDocsFilepaths& recentDocsFilepaths,
                                                       sigc::slot<void, const std::string&>& recent_doc_open_action,
                                                       sigc::slot<void, const std::string&>& recent_doc_rm_action);
-    Gtk::Menu*                 build_special_chars_menu(const Glib::ustring& specialChars,
-                                                        sigc::slot<void, gunichar>& spec_char_action);
 
     Gtk::Menu*                 get_popup_menu(POPUP_MENU_TYPE popupMenuType);
     void                       build_popup_menu(Gtk::Menu* pMenu, POPUP_MENU_TYPE popupMenuType);
@@ -95,7 +93,9 @@ private:
     void                    _walk_menu_xml(Gtk::MenuShell* pMenuShell, const char* document, const char* xpath);
     void                    _walk_menu_xml(Gtk::MenuShell* pMenuShell, xmlpp::Node* pNode);
     Gtk::Menu*              _add_menu_submenu(Gtk::MenuShell* pMenuShell, const char* id, const char* name, const char* image);
-    Gtk::MenuItem*          _add_menu_item(Gtk::MenuShell* pMenuShell, CtMenuAction* pAction);
+    Gtk::MenuItem*          _add_menu_item(Gtk::MenuShell* pMenuShell,
+                                           CtMenuAction* pAction,
+                                           std::list<sigc::connection>* pListConnections = nullptr);
     static Gtk::MenuItem*   _add_menu_item(Gtk::MenuShell* pMenuShell,
                                            const char* name,
                                            const char* image,
@@ -105,6 +105,7 @@ private:
                                            gpointer action_data,
                                            sigc::signal<void, bool>* signal_set_sensitive,
                                            sigc::signal<void, bool>* signal_set_visible,
+                                           std::list<sigc::connection>* pListConnections = nullptr,
                                            const bool use_underline = true);
     static void             _add_menu_item_image_or_label(Gtk::MenuItem* pMenuItem, const char* image, Gtk::AccelLabel* label);
     Gtk::SeparatorMenuItem* _add_menu_separator(Gtk::MenuShell* pMenuShell);
@@ -114,6 +115,7 @@ private:
     const char*              _get_popup_menu_ui_str_text();
     const char*              _get_popup_menu_ui_str_code();
     const char*              _get_popup_menu_ui_str_image();
+    const char*              _get_popup_menu_ui_str_latex();
     const char*              _get_popup_menu_ui_str_anchor();
     const char*              _get_popup_menu_ui_str_embfile();
 
@@ -123,4 +125,5 @@ private:
     Glib::RefPtr<Gtk::Builder>    _rGtkBuilder;
     Glib::RefPtr<Gtk::AccelGroup> _pAccelGroup;
     Gtk::Menu*                    _popupMenus[POPUP_MENU_TYPE::PopupMenuNum] = {};
+    std::list<sigc::connection>   _curr_bookm_submenu_sigc_conn;
 };
