@@ -1,7 +1,7 @@
 /*
  * ct_menu_ui.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -154,6 +154,7 @@ const char* CtMenu::_get_ui_str_menu()
     <menuitem action='handle_image'/>
     <menuitem action='handle_table'/>
     <menuitem action='handle_codebox'/>
+    <menuitem action='handle_latex'/>
     <menuitem action='handle_embfile'/>
     <menuitem action='handle_link'/>
     <menuitem action='handle_anchor'/>
@@ -214,10 +215,11 @@ const char* CtMenu::_get_ui_str_menu()
   <menu action='ToolsMenu'>
     <menuitem action='spellcheck_toggle'/>
     <separator/>
+    <menuitem action='exec_code'/>
     <menuitem action='strip_trail_spaces'/>
+    <menuitem action='repl_tabs_spaces'/>
     <separator/>
     <menuitem action='command_palette'/>
-    <menuitem action='exec_code'/>
   </menu>
 
   <menu action='TreeMenu'>
@@ -228,6 +230,8 @@ const char* CtMenu::_get_ui_str_menu()
     <menuitem action='tree_add_subnode'/>
     <menuitem action='tree_dup_node'/>
     <menuitem action='tree_dup_node_subnodes'/>
+    <menuitem action='tree_copy_node_subnodes'/>
+    <menuitem action='tree_paste_node_subnodes'/>
     <menuitem action='tree_node_date'/>
     <separator/>
     <menuitem action='tree_node_prop'/>
@@ -325,8 +329,6 @@ const char* CtMenu::_get_popup_menu_ui_str_text()
     <menuitem action='mv_up_row'/>
     <menuitem action='mv_down_row'/>
     <menuitem action='del_row'/>
-    <separator/>
-    <menuitem action='strip_trail_spaces'/>
   </menu>
   <menu action='FormattingSubMenu'>
     <menuitem action='fmt_clone'/>
@@ -375,6 +377,7 @@ const char* CtMenu::_get_popup_menu_ui_str_text()
     <menuitem action='handle_image'/>
     <menuitem action='handle_table'/>
     <menuitem action='handle_codebox'/>
+    <menuitem action='handle_latex'/>
     <menuitem action='handle_embfile'/>
     <menuitem action='handle_link'/>
     <menuitem action='handle_anchor'/>
@@ -388,6 +391,7 @@ const char* CtMenu::_get_popup_menu_ui_str_text()
       <menuitem action='handle_todo_list'/>
     </menu>
   </menu>
+  <menuitem action='strip_trail_spaces'/>
   <separator/>
   <menu action='FindSubMenu'>
     <menuitem action='find_in_node'/>
@@ -414,6 +418,8 @@ const char* CtMenu::_get_popup_menu_ui_str_code()
   <menuitem action='copy_plain'/>
   <separator/>
   <menuitem action='exec_code'/>
+  <menuitem action='strip_trail_spaces'/>
+  <menuitem action='repl_tabs_spaces'/>
   <menu action='InsertSubMenu'>
     <menuitem action='insert_timestamp'/>
     <menuitem action='insert_special_char'/>
@@ -431,8 +437,6 @@ const char* CtMenu::_get_popup_menu_ui_str_code()
     <menuitem action='dup_row'/>
     <menuitem action='mv_up_row'/>
     <menuitem action='mv_down_row'/>
-  <separator/>
-    <menuitem action='strip_trail_spaces'/>
   </menu>
   <separator/>
   <menu action='FindSubMenu'>
@@ -468,6 +472,20 @@ const char* CtMenu::_get_popup_menu_ui_str_image()
     )MARKUP";
 }
 
+const char* CtMenu::_get_popup_menu_ui_str_latex()
+{
+    return R"MARKUP(
+<popup>
+  <menuitem action='tex_cut'/>
+  <menuitem action='tex_copy'/>
+  <menuitem action='tex_del'/>
+  <separator/>
+  <menuitem action='tex_edit'/>
+  <menuitem action='tex_save'/>
+</popup>
+    )MARKUP";
+}
+
 const char* CtMenu::_get_popup_menu_ui_str_anchor()
 {
     return R"MARKUP(
