@@ -116,7 +116,7 @@ public:
     void wipe();
 
 private:
-    const CtConfig* _pCtConfig = nullptr;
+    const CtConfig* const _pCtConfig;
     std::unordered_map<std::string_view, bool> _open_tags;
 
     xmlpp::Element* _build_root_el();
@@ -127,6 +127,7 @@ private:
     xmlpp::Element* _current_element = nullptr;
     xmlpp::Element* _last_element = nullptr;
     broken_links_t _broken_links;
+    int _currOffset{0};
 };
 
 /**
