@@ -84,6 +84,8 @@ Gtk::Widget* CtPrefDlg::build_tab_rich_text()
     spinbutton_limit_undoable_steps->set_value(_pConfig->limitUndoableSteps);
     hbox_misc_text->pack_start(*label_limit_undoable_steps, false, false);
     hbox_misc_text->pack_start(*spinbutton_limit_undoable_steps, false, false);
+    Gtk::CheckButton* checkbutton_camelcase_autolink = Gtk::manage(new Gtk::CheckButton{_("Auto Link CamelCase Text to Node With Same Name")});
+    checkbutton_camelcase_autolink->set_active(_pConfig->camelCaseAutoLink);
     Gtk::CheckButton* checkbutton_triple_click_sel_paragraph = Gtk::manage(new Gtk::CheckButton(_("At Triple Click Select the Whole Paragraph")));
     checkbutton_triple_click_sel_paragraph->set_active(_pConfig->tripleClickParagraph);
 #ifdef MD_AUTO_REPLACEMENT
@@ -100,6 +102,7 @@ Gtk::Widget* CtPrefDlg::build_tab_rich_text()
     vbox_misc_text->pack_start(*hbox_embfile_max_size, false, false);
     vbox_misc_text->pack_start(*checkbutton_embfile_show_filename, false, false);
     vbox_misc_text->pack_start(*hbox_misc_text, false, false);
+    vbox_misc_text->pack_start(*checkbutton_camelcase_autolink, false, false);
     vbox_misc_text->pack_start(*checkbutton_triple_click_sel_paragraph, false, false);
 #ifdef MD_AUTO_REPLACEMENT
     vbox_misc_text->pack_start(*checkbutton_md_formatting, false, false);
@@ -164,6 +167,9 @@ Gtk::Widget* CtPrefDlg::build_tab_rich_text()
     spinbutton_limit_undoable_steps->signal_value_changed().connect([this, spinbutton_limit_undoable_steps](){
         _pConfig->limitUndoableSteps = spinbutton_limit_undoable_steps->get_value_as_int();
     });
+    checkbutton_camelcase_autolink->signal_toggled().connect([this, checkbutton_camelcase_autolink]{
+        _pConfig->camelCaseAutoLink = checkbutton_camelcase_autolink->get_active();
+    });
     checkbutton_triple_click_sel_paragraph->signal_toggled().connect([this, checkbutton_triple_click_sel_paragraph]{
         _pConfig->tripleClickParagraph = checkbutton_triple_click_sel_paragraph->get_active();
     });
