@@ -360,7 +360,6 @@ TEST(MiscUtilsGroup, mime__type_contains)
 // some tests don't work on TRAVIS with WIN32
 #if !(defined(_TRAVIS) && defined(_WIN32))
     ASSERT_TRUE(CtMiscUtil::mime_type_contains(UT::unitTestsDataDir+"/mimetype_txt.txt", "text/"));
-    ASSERT_TRUE(CtMiscUtil::mime_type_contains(UT::unitTestsDataDir+"/mimetype_html.html", "text/"));
     ASSERT_TRUE(CtMiscUtil::mime_type_contains(UT::unitTestsDataDir+"/mimetype_html.html", "html"));
 
 // test doesn't work on WIN32 and MacOS
@@ -463,3 +462,19 @@ TEST(MiscUtilsGroup, get_is_camel_case)
         ASSERT_TRUE(CtTextIterUtil::get_is_camel_case(pTextBuffer->begin(), yesCamel2.size()));
     }
 }
+
+TEST(MiscUtilsGroup, gtk_pango_find_base_dir)
+{
+    ASSERT_EQ(PANGO_DIRECTION_LTR, CtStrUtil::gtk_pango_find_base_dir("Test 123", -1));
+    ASSERT_EQ(PANGO_DIRECTION_RTL, CtStrUtil::gtk_pango_find_base_dir("זה טקסט שנכתב בעברית, מימין לשמאל, עם סימני פיסוק! וגם; מספרים כמו", -1));
+}
+
+TEST(MiscUtilsGroup, gtk_pango_find_start_of_dir)
+{
+    ASSERT_EQ(0, CtStrUtil::gtk_pango_find_start_of_dir("Test 123", PANGO_DIRECTION_LTR));
+    ASSERT_EQ(-1, CtStrUtil::gtk_pango_find_start_of_dir("Test 123", PANGO_DIRECTION_RTL));
+    ASSERT_EQ(0, CtStrUtil::gtk_pango_find_start_of_dir("זה טקסט שנכתב בעברית, מימין לשמאל, עם סימני פיסוק! וגם; מספרים כמו", PANGO_DIRECTION_RTL));
+    ASSERT_EQ(-1, CtStrUtil::gtk_pango_find_start_of_dir("זה טקסט שנכתב בעברית, מימין לשמאל, עם סימני פיסוק! וגם; מספרים כמו", PANGO_DIRECTION_LTR));
+    ASSERT_EQ(8, CtStrUtil::gtk_pango_find_start_of_dir("Test 123" "עִבְרִית", PANGO_DIRECTION_RTL));
+    ASSERT_EQ(16, CtStrUtil::gtk_pango_find_start_of_dir("עִבְרִית" "Test 123", PANGO_DIRECTION_LTR));
+}
\ No newline at end of file
